@@ -33,8 +33,8 @@ utils::globalVariables(c("silentText","silentGraph","silentLegend","initialType"
 #' used to calculated variances of parameters of the model.
 #' @return Object of class "smooth" is returned. See \link[smooth]{ces} for
 #' details.
-#' @seealso \code{\link[smooth]{ces}, \link[forecast]{ets},
-#' \link[forecast]{forecast}, \link[stats]{ts}}
+#' @seealso \code{\link[smooth]{ces}, \link[smooth]{es},
+#' \link[greybox]{forecast}, \link[stats]{ts}}
 #'
 #' @examples
 #'
@@ -43,12 +43,11 @@ utils::globalVariables(c("silentText","silentGraph","silentLegend","initialType"
 #' auto.ces(y,h=20,holdout=TRUE)
 #' auto.ces(y,h=20,holdout=FALSE)
 #'
-#' library("Mcomp")
-#' \dontrun{y <- ts(c(M3$N0740$x,M3$N0740$xx),start=start(M3$N0740$x),frequency=frequency(M3$N0740$x))
+#' \dontrun{
 #' # Selection between "none" and "full" seasonalities
-#' auto.ces(y,h=8,holdout=TRUE,models=c("n","f"),interval="p",level=0.8,ic="AIC")}
+#' auto.ces(AirPassengers,h=8,holdout=TRUE,models=c("n","f"),interval="p",level=0.8,ic="AIC")}
 #'
-#' ourModel <- auto.ces(M3[[1683]],interval="sp")
+#' ourModel <- auto.ces(AirPassengers,interval="sp")
 #'
 #' summary(ourModel)
 #' forecast(ourModel)
@@ -57,7 +56,7 @@ utils::globalVariables(c("silentText","silentGraph","silentLegend","initialType"
 #' @export auto.ces
 auto.ces <- function(y, models=c("none","simple","full"),
                 initial=c("backcasting","optimal"), ic=c("AICc","AIC","BIC","BICc"),
-                loss=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
+                loss=c("likelihood","MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
                 h=10, holdout=FALSE, cumulative=FALSE,
                 interval=c("none","parametric","likelihood","semiparametric","nonparametric"), level=0.95,
                 bounds=c("admissible","none"),
