@@ -55,7 +55,7 @@ utils::globalVariables(c("silentText","silentGraph","silentLegend","initialType"
 #' Maximum order of MA term. Can be vector, defining max orders of MA, SMA etc.
 #' @return Object of class "smooth" is returned. See \link[smooth]{ssarima} for
 #' details.
-#' @seealso \code{\link[forecast]{ets}, \link[smooth]{es}, \link[smooth]{ces},
+#' @seealso \code{\link[smooth]{es}, \link[smooth]{ces},
 #' \link[smooth]{sim.es}, \link[smooth]{gum}, \link[smooth]{ssarima}}
 #'
 #' @examples
@@ -83,7 +83,7 @@ utils::globalVariables(c("silentText","silentGraph","silentLegend","initialType"
 auto.ssarima <- function(y, orders=list(ar=c(3,3),i=c(2,1),ma=c(3,3)), lags=c(1,frequency(y)),
                          combine=FALSE, fast=TRUE, constant=NULL,
                          initial=c("backcasting","optimal"), ic=c("AICc","AIC","BIC","BICc"),
-                         loss=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
+                         loss=c("likelihood","MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
                          h=10, holdout=FALSE, cumulative=FALSE,
                          interval=c("none","parametric","likelihood","semiparametric","nonparametric"), level=0.95,
                          bounds=c("admissible","none"),
