@@ -21,6 +21,3 @@ x <- cbind(rnorm(length(M3$N2457$x),50,3),rnorm(length(M3$N2457$x),100,7))
 ## ----auto_ces_N2457_xreg_simple-----------------------------------------------
 auto.ces(M3$N2457$x, h=18, holdout=TRUE, xreg=x, xregDo="select", interval="p")
 
-## ----auto_ces_N2457_xreg_update-----------------------------------------------
-auto.ces(M3$N2457$x, h=18, holdout=TRUE, xreg=x, updateX=TRUE, interval="p")
-
